# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ChromatographyType, ComponentInfo, DoubleRange

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant

class CalibrationLevels:  # Class
    INVALID_LEVEL_INDEX: int  # static

    IsGCData: bool  # readonly
    LevelCount: int  # readonly
    MaxLevelIndex: int  # readonly
    MinLevelIndex: int  # readonly
    SampleCount: int  # readonly
    StartingLevelIndex: int  # readonly

    def GetSamplesAtLevelIndex(
        self, levelIndex: int
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]: ...
    def GetSamplesByLevelConcentration(
        self, levelConcentration: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]: ...
    def GetLevelIndexByConcentration(self, conc: float) -> int: ...
    def GetLevelIndexForSample(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> int: ...
    def GetSamplesByLevel(
        self, level: str
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]: ...
    def GetSampleByPath(
        self, sampleDataPath: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ): ...
    def GetReplicatesForSample(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]: ...
    def GetLevelIndexByLevel(self, level: str) -> int: ...
    def GetConcentrationByLevelIndex(self, levelIndex: int) -> float: ...
    def GetLevelByIndex(self, levelIndex: int) -> str: ...

class CalibrationSample:  # Class
    def __init__(
        self, sampleDirPath: str, level: str, concentration: float
    ) -> None: ...

    ChromType: ChromatographyType  # readonly
    Concentration: float  # readonly
    CurrentScanConditions: (
        Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    )  # readonly
    DataDirPath: str  # readonly
    FeatureDataAccess: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.TofFeatureDataAccess
    )  # readonly
    IsAllIonsData: bool  # readonly
    IsGCData: bool  # readonly
    Level: str  # readonly
    ScanConditionList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ]  # readonly

    def GetFeatureSet(
        self,
        refSpectrumScanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.IFeatureSet: ...
    def Open(self) -> bool: ...
    def GetFeaturesInRange(
        self,
        scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
        targetMz: float,
        rtRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD,
        mzRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def GetFeatureByID(
        self,
        scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
        featureID: int,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FD.Feature: ...
    def Close(self) -> None: ...
    def ContainsDataForScanConditions(
        self, refScanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> bool: ...
    def GetFeaturesInMzRange(
        self,
        scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions,
        targetMz: float,
        mzRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FD.Feature
    ]: ...
    def GetNoiseFactor2(
        self, scanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions
    ) -> float: ...

class CalibrationSampleList(
    Iterable[Any],
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ],
):  # Class
    def __init__(self, sampleListFilePath: str) -> None: ...

    BatchDirectory: str  # readonly
    Count: int  # readonly
    IsAllIonsData: bool  # readonly
    IsGCData: bool  # readonly
    Levels: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels
    )  # readonly
    SampleListFile: str  # readonly
    Samples: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]  # readonly

    def GetSampleListSortedByConcentration(
        self, reverse: bool
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    ]: ...

    # Nested Types

    class ReverseConcentrationComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
            b: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
        ) -> int: ...

class CoelutingFeatureGroup(
    Iterable[Any],
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ],
):  # Class
    @overload
    def __init__(
        self,
        cpdFeaturesInSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample,
        component: Agilent.MassSpectrometry.DataAnalysis.Component,
    ) -> None: ...
    @overload
    def __init__(
        self,
        cpdFeaturesInSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample,
        largestFeature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> None: ...

    AssignedRT: float  # readonly
    FeatureCount: int  # readonly
    LibraryMatchScore: float  # readonly
    RTRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    )  # readonly
    ShapeQualityScore: float  # readonly
    TargetCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly

    def GetFeatureByReferenceIon(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ): ...
    def Add(
        self,
        feature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    def SatisfiesAbundanceScalingConstraint(
        self,
        lowerLevelGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup,
    ) -> bool: ...
    def AddFeatureNoCheck(
        self,
        feature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> None: ...
    @overload
    def IsAlignedWith(
        self,
        feature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    @overload
    def IsAlignedWith(
        self,
        featureGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup,
    ) -> bool: ...
    def ComputeLibraryMatchScore(
        self,
        refLibrary: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary,
    ) -> None: ...
    def GetFeatureSpectrum(
        self, mzValues: List[float], abundanceValues: List[float]
    ) -> None: ...

class CompoundFeaturesInSample:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        spectra: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
        ],
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...

    CoelutingFeatureGroups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup
    ]  # readonly
    NCoelutingGroups: int  # readonly
    NFeatures: int  # readonly
    RefSpectra: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ]  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    )  # readonly
    TargetCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly

    def FilterCoelutingGroupsByLibraryMatchScore(
        self, minScore: float, maxGroupCount: int, minGroupCount: int
    ) -> None: ...
    def GetFeatureByID(
        self, featureID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ): ...
    def GetFeaturesByReferenceSpectrum(
        self,
        refSpectrum: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumFeaturesInSample
    ): ...
    def GetRefIonFeatures(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ]: ...
    def ComputeLibraryMatchScores(
        self,
        refLibrary: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary,
    ) -> None: ...
    def FindCoelutingFeatureGroups(self) -> None: ...
    def GetFeaturesInSampleByReferenceIon(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.FeatureListForRefIonInSample
    ): ...

class CompoundMethodAssistant:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        refSpectra: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
        ],
        levels: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...

    AlternativeGroupClusters: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroupCluster
    ]  # readonly
    BestTargetGroupCluster: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroupCluster
    )  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    CrossSampleTargetSearch_Combined: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetSearch
    )  # readonly
    CrossSampleTargetSearch_Separate: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetSearch
    )  # readonly
    HasAltClusters: bool  # readonly
    HasIsomers: bool  # readonly
    IsomerCount: int  # readonly
    ProcessedSampleCount: int  # readonly
    RefSpectra: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ]  # readonly
    ReferenceSpectrumLibrary: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary
    )  # readonly

    def DebugWriteTargetCompoundCandidates(
        self, sw: System.IO.StreamWriter
    ) -> None: ...
    def DebugWriteTargetCompoundCandidates_AllIons(
        self, sw: System.IO.StreamWriter
    ) -> None: ...
    def FindCrossSampleTargetHitGroups(self, resolveTargetAmbiguity: bool) -> None: ...
    def GetCrossSampleTargetSearch(
        self, separateScanConditions: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetSearch
    ): ...
    def ExtractCompoundFeatures(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample
    ): ...
    def FindTargetHitsInSample(
        self,
        cpdFeaturesInSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample,
        resolveTargetAmbiguity: bool,
    ) -> None: ...
    @overload
    def CollectBestAndAltTargetHitGroups(
        self,
        targetSelector: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitGroupSelector,
    ) -> None: ...
    @overload
    def CollectBestAndAltTargetHitGroups(
        self,
        targetSelector_Separate: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitGroupSelector,
        targetSelector_Combined: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitGroupSelector,
    ) -> None: ...
    def DebugWriteTargetHitGroups(self, sw: System.IO.StreamWriter) -> None: ...
    def GetCompoundFeaturesForSample(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample
    ): ...

class CrossSampleFeatureGroup:  # Class
    def __init__(
        self,
        refIonFeature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
        levels: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels,
    ) -> None: ...

    AverageMzErrorPpm: float  # readonly
    AverageRT: float  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    FeatureRTRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD  # readonly
    IsContiguous: bool  # readonly
    IsGCData: bool  # readonly
    IsNonMonotonic: bool  # readonly
    LevelCount: int  # readonly
    MaxLevelIndex: int  # readonly
    MedianMzErrorPpm: float  # readonly
    MinLevelIndex: int  # readonly
    QualityMetric: float  # readonly
    RefIon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    )  # readonly
    RelativeDynamicRange: float  # readonly
    ScalingQualityMetric: float  # readonly
    TotalFeatureCount: int  # readonly
    TotalLevelCount: int  # readonly

    def GetAverageMzErrorPpmByLevelIndex(self, levelIndex: int) -> float: ...
    def GetAverageMzByLevelIndex(self, levelIndex: int) -> float: ...
    def AddRefIonFeature(
        self,
        refIonFeature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    def ContainsFeatureAtLevel(self, levelIndex: int) -> bool: ...
    def OverlapsFeatureInRT(
        self,
        feature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    def GetResponseVsConcentrationTable(
        self, nLowestLevels: int, concentrations: List[float], responses: List[float]
    ) -> None: ...
    def GetAverageRTByLevelIndex(self, levelIndex: int) -> float: ...
    def GetFeaturesByLevelIndex(
        self, levelIndex: int
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ]: ...
    def GetFirstPopulatedLevelIndexAbove(self, levelIndex: int) -> int: ...
    def CanContainFeature(
        self,
        feature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    def GetAverageCoelutionCountByLevelIndex(self, levelIndex: int) -> float: ...
    def GetAverageAreaByLevelIndex(self, levelIndex: int) -> float: ...
    def GetFirstPopulatedLevelIndexBelow(self, levelIndex: int) -> int: ...
    def FindFeatureFromSample(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ): ...
    def GetAverageHeightByLevelIndex(self, levelIndex: int) -> float: ...
    def GetAverageResponseFactorByLevelIndex(self, levelIndex: int) -> float: ...

class CrossSampleFeatureGroupCluster:  # Class
    def __init__(
        self,
        firstGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup,
    ) -> None: ...

    AssignedRT: float  # readonly
    AverageGroupMassAccuracyPpm: float  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    FeatureGroups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup
    ]  # readonly
    GroupCount: int  # readonly
    GroupRTs: List[float]  # readonly
    MassAccuracyMetric: float  # readonly
    MaxDynamicRangeGroup: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup
    )  # readonly
    MaxGroupDynamicRangeInLevels: int  # readonly
    MedianGroupMassAccuracyPpm: float  # readonly
    QualityMetric: float  # readonly
    QualityMetricNoGroupCount: float  # readonly
    RTRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD  # readonly

    def AddGroup(
        self,
        group: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup,
    ) -> None: ...
    def Overlaps(
        self,
        group: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup,
    ) -> bool: ...
    def SortGroupsByDynamicRange(self) -> None: ...
    def CheckReferenceSpectrumConsistency(self, allSpectraMustPass: bool) -> bool: ...
    def GetFeatureGroupByRank(
        self, rankIndex: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup
    ): ...
    def SortGroupsByQualityMetric(self) -> None: ...
    def SortGroupsByDynamicRangeAndQuality(self) -> None: ...
    def GetFeatureGroupByRefIon(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroup
    ): ...

class CrossSampleTargetHitGroup:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        samples: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
        ],
        levels: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels,
        firstTargetHit: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
    ) -> None: ...

    AssignedRT: float  # readonly
    AverageLMS: float  # readonly
    AverageRT: float  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    DynamicRangeInLevels: int  # readonly
    DynamicRangeScore: float  # readonly
    FeatureGroupCluster: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleFeatureGroupCluster
    )  # readonly
    ID: int  # readonly
    LMSStdError: float  # readonly
    MassScore: float  # readonly
    MaxLMS: float  # readonly
    MaxLevelIndex: int  # readonly
    MaxRT: float  # readonly
    MaxRTRange: DoubleRange  # readonly
    MedianLMS: float  # readonly
    MedianRT: float  # readonly
    MinLMS: float  # readonly
    MinLevelIndex: int  # readonly
    MinRT: float  # readonly
    QualityScore: float  # readonly
    RT3SigmaRange: DoubleRange  # readonly
    RTStdError: float  # readonly
    SampleCount: int  # readonly
    ScalingQualityMetric: float  # readonly
    TotalLevelCount: int  # readonly

    def AddTargetHit(
        self,
        targetHit: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
    ) -> None: ...
    def GetAverageLMSByLevelIndex(self, levelIndex: int) -> float: ...
    @overload
    @staticmethod
    def ComputeCrossCorrelationScore(
        targetHit: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
        dotProduct: Agilent.MassSpectrometry.DataAnalysis.DotProductSearch,
    ) -> float: ...
    @overload
    @staticmethod
    def ComputeCrossCorrelationScore(
        tgt: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
        rfs: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
        dotProduct: Agilent.MassSpectrometry.DataAnalysis.DotProductSearch,
    ) -> float: ...
    def GetAverageRTByLevelIndex(self, levelIndex: int) -> float: ...
    def ContainsTargetHitsAtLevel(self, levelIndex: int) -> bool: ...
    def ConvertToTargetFeatureGroupCluster(self) -> None: ...
    def GetAverageIonCountByLevelIndex(self, levelIndex: int) -> float: ...
    def ContainsTargetHitInSample(
        self,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
    ) -> bool: ...
    def GetAverageAreaByLevelIndex(self, levelIndex: int) -> float: ...
    def GetAverageHeightByLevelIndex(self, levelIndex: int) -> float: ...
    def OverlapsInRT(
        self,
        targetHit: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo,
    ) -> bool: ...

class CrossSampleTargetSearch:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        levels: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels,
        refLibrary: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary,
        separateScanConditions: bool,
    ) -> None: ...

    BestGroupByDynamicRange: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    BestGroupByLMS: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    BestGroupByMass: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    BestGroupByQuality: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    HitGroupCount: int  # readonly
    IsUnambiguous: bool  # readonly
    IsUnique: bool  # readonly
    NoGroupsFound: bool  # readonly
    SecondBestGroupByQuality: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    SeparateScanConditions: bool  # readonly
    TargetHitGroups: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]  # readonly

    def DebugWriteTargetHitGroupSummary(self, sw: System.IO.StreamWriter) -> None: ...
    def FilterTargetHitGroupsByMinDynamicRange(self, minLevels: int) -> None: ...
    def FindTargetCandidatesInRange(
        self, rtSearchRange: DoubleRange
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCandidatesInRTRange
    ): ...
    def FindTargetHitGroups(self) -> None: ...
    def EvaluateTargetHits(self) -> None: ...
    def FindTargetHitsInSample(
        self,
        cpdFeaturesInSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample,
    ) -> None: ...
    def ComputeMassAccuracyMetrics(self) -> None: ...
    def DebugWriteGroupSummary(self, sw: System.IO.StreamWriter) -> None: ...
    def DebugWriteTargetHitGroups(self, sw: System.IO.StreamWriter) -> None: ...
    def PopulateTargetHitGroups(self) -> None: ...

class FeatureListForRefIonInSample(
    Iterable[Any],
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ],
):  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...

    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    FeatureCount: int  # readonly
    ReferenceIon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    )  # readonly

    def Contains(
        self,
        f: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...
    def GetFeaturesInRange(
        self, mzDeltaPpm: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ]: ...
    def AppendRefIonFeaturesToList(
        self,
        featureList: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
        ],
    ) -> None: ...

class IsomerSet:  # Class
    Compounds: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ]  # readonly
    Count: int  # readonly
    Formula: str  # readonly
    HasImplicitOrder: bool  # readonly
    Name: str  # readonly

    def GetImplicitOrderIndexForIsomerCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> int: ...
    def ContainsCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> bool: ...
    def AddIsomerCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> bool: ...
    def FinalizeIsomerSet(self) -> None: ...
    def GetIsomerByName(
        self, cpdName: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ): ...
    def GetIsomerByIndexInImplicitOrder(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ): ...

class MethodAssistantParameters:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, xmlFilePath: str) -> None: ...

    DEFAULT_ADDUCTS: List[str]  # static # readonly
    DEFAULT_MZ_EXTRACTION_DELTA_PPM: float = ...  # static # readonly
    DEFAULT_XML_PARAM_FILE: str = ...  # static # readonly
    HIGH_MZ_EXTRACTION_DELTA_PPM: float = ...  # static # readonly
    H_PLUS_ADDUCT: str = ...  # static # readonly
    K_PLUS_ADDUCT: str = ...  # static # readonly
    LOW_MZ_EXTRACTION_DELTA_PPM: float = ...  # static # readonly
    MAX_IONS_IN_ISOTOPE_PATTERN: int = ...  # static # readonly
    MAX_IONS_PER_SPECTRUM: int = ...  # static # readonly
    MIN_IONS_PER_SPECTRUM: int = ...  # static # readonly
    MIN_REF_ION_RELATIVE_ABUNDANCE: float = ...  # static # readonly
    MIN_RELATIVE_ISOTOPE_ABUNDANCE: float = ...  # static # readonly
    NH4_PLUS_ADDUCT: str = ...  # static # readonly
    NUM_QUALIFIERS_DESIRED: int = ...  # static # readonly
    Na_PLUS_ADDUCT: str = ...  # static # readonly
    QUANT_METHOD_RT_EXTRACTION_DELTA_GC: float = ...  # static # readonly
    QUANT_METHOD_RT_EXTRACTION_DELTA_LC: float = ...  # static # readonly
    RESOLVE_TARGET_RT_AMBIGUITY: bool = ...  # static # readonly
    RT_TARGET_SEARCH_RANGE_DELTA: float = ...  # static # readonly
    SEARCH_ENTIRE_CHROMATOGRAPHIC_RANGE: bool = ...  # static # readonly

    AdductFormulas: List[str]
    DefaultMzDeltaPpm: float
    HasUnrecognizedAdducts: bool  # readonly
    HighMzDeltaPpm: float
    LowMzDeltaPpm: float
    MaxIonsInIsotopePattern: int
    MaxIonsPerSpectrum: int
    MethodRTExtractionDelta: float
    MinIonsPerSpectrum: int
    MinRefIonRelativeAbundance: float
    MinRelativeIsotopeAbundance: float
    NQualifiers: int
    OutputMethodFilePath: str
    RTTargetSearchRangeDelta: float
    ResolveTargetRTAmbiguity: bool
    SearchEntireChromatographicRange: bool
    UnrecognizedAdducts: List[str]  # readonly

class MethodAssistantRunCompleted(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, sender: Any, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any) -> None: ...

class MethodAssistantRunStarting(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        nSamples: int,
        nCompounds: int,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, nSamples: int, nCompounds: int) -> None: ...

class QuantMethodAssistant(System.IDisposable):  # Class
    @overload
    def __init__(
        self, sampleListFilePath: str, compoundListFilePath: str, refLibraryPath: str
    ) -> None: ...
    @overload
    def __init__(
        self,
        sampleListFilePath: str,
        compoundListFilePath: str,
        refLibraryPath: str,
        optParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...

    CalibrationLevels: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationLevels
    )  # readonly
    CompoundList: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList
    )  # readonly
    NCompounds: int  # readonly
    Parameters: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters
    )  # readonly
    SampleList: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSampleList
    )  # readonly

    def CreateQuantMethod(self) -> None: ...
    def Dispose(self) -> None: ...
    def FindQuantTargets(self) -> None: ...

    RunCompleted: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantRunCompleted
    )  # Event
    RunStarting: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantRunStarting
    )  # Event
    SampleProcessed: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.SampleProcessed
    )  # Event
    SampleProcessingStarting: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.SampleProcessingStarting
    )  # Event

class RefIonFeature:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
        feature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature,
    ) -> None: ...

    Area: float  # readonly
    CoelutingFeatureGroupInSample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup
    )  # readonly
    CoelutionCount: int  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    FWHM: float  # readonly
    Feature: Agilent.MassSpectrometry.DataAnalysis.FD.Feature  # readonly
    FeatureID: int  # readonly
    Height: float  # readonly
    IsSaturated: bool  # readonly
    MZ: float  # readonly
    MzErrorPpm: float  # readonly
    RT: float  # readonly
    RTRange: Agilent.MassSpectrometry.DataAnalysis.DoubleRangeD  # readonly
    RefIon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    )  # readonly
    ResponseFactor: float  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    )  # readonly

    def ReleaseFeature(self) -> None: ...
    def OverlapsInRT(
        self,
        otherFeature: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature,
    ) -> bool: ...

class ReferenceIon:  # Class
    def __init__(
        self,
        parentSpectrum: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum,
        mz: float,
        abundance: float,
    ) -> None: ...

    Abundance: float  # readonly
    IntegerMZ: int  # readonly
    MZ: float  # readonly
    Polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity  # readonly
    Spectrum: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    )  # readonly

class ReferenceSpectrum(
    Iterable[Any],
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ],
    System.IEquatable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ],
):  # Class
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary,
        spectrumRow: Agilent.MassSpectrometry.DataAnalysis.LibraryDataSet.SpectrumRow,
        maxRefIons: int,
        minRefIons: int,
        minRelativeAbundance: float,
    ) -> None: ...

    Adduct: Agilent.MassSpectrometry.DataAnalysis.MFS.IAdductIon  # readonly
    BaseIon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    )  # readonly
    CollisionEnergy: float  # readonly
    FragmentorVoltage: float  # readonly
    HasRetentionTime: bool  # readonly
    IonCount: int  # readonly
    IonsSortedByAbundance: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ]  # readonly
    Polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity  # readonly
    RT: float  # readonly
    ScanConditions: Agilent.MassSpectrometry.DataAnalysis.FD.ScanConditions  # readonly
    ScanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType  # readonly
    SelectedMZ: float  # readonly

    def Equals(
        self,
        other: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum,
    ) -> bool: ...
    def GetTopReferenceIonsByAbundance(
        self, nIons: int
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ]: ...
    def GetReferenceIonByIndex(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ): ...
    def GetReferenceIonByMz(
        self, mz: float
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ): ...
    @staticmethod
    def MapSpeciesToAdduct(
        spectrum: Agilent.MassSpectrometry.DataAnalysis.LibraryDataSet.SpectrumRow,
    ) -> Agilent.MassSpectrometry.DataAnalysis.MFS.IAdductIon: ...
    def ContainsIonAtIntegerMZ(self, integerMz: int) -> bool: ...

class ReferenceSpectrumFeaturesInSample:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        spectrum: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum,
        sample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...
    def GetFeaturesForAllRefIonsInSpectrum(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ]: ...
    def GetFeatureListForRefIon(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.FeatureListForRefIonInSample
    ): ...

class ReferenceSpectrumLibrary:  # Class
    @overload
    def __init__(
        self,
        libraryPath: str,
        compoundList: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...
    @overload
    def __init__(
        self,
        compoundList: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList,
        maParams: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.MethodAssistantParameters,
    ) -> None: ...

    Library: Agilent.MassSpectrometry.DataAnalysis.ILibrary  # readonly
    LibraryPath: str  # readonly

    def GetSpectraForCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ]: ...
    def ComputeBestReverseMatchScore(
        self,
        featureGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup,
    ) -> float: ...
    def CloseLibrary(self) -> None: ...
    def GetSpectraByName(
        self, cpdName: str
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ]: ...
    def ComputeReverseMatchScores(
        self,
        featureGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CoelutingFeatureGroup,
    ) -> Dict[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum,
        float,
    ]: ...
    def ComputeMatchScores(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        component: Agilent.MassSpectrometry.DataAnalysis.Component,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.CandidateHit
    ]: ...
    def GetSpectraByCAS(
        self, casNumber: str
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrum
    ]: ...
    def ComputeForwardMatchScores(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        component: Agilent.MassSpectrometry.DataAnalysis.Component,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.CandidateHit
    ]: ...

class RetentionTimeAlignment:  # Class
    def __init__(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
        ],
    ) -> None: ...

    SampleCount: int  # readonly

    def RunTICBasedAlignment(self) -> None: ...

class SampleProcessed(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        sampleDataPath: str,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, sampleDataPath: str) -> None: ...

class SampleProcessingStarting(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        sampleDataPath: str,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, sampleDataPath: str) -> None: ...

class TargetCandidatesInRTRange:  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
        targetHitGroups: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
        ],
        rtSearchRange: DoubleRange,
    ) -> None: ...

    BestCandidateByLMS: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    BestCandidateByQualityScore: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    )  # readonly
    CandidateHitGroups: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]  # readonly
    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    CountInRange: int  # readonly
    FirstRT: float  # readonly
    HitGroupsInRange: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]  # readonly
    LastRT: float  # readonly
    LibraryMatchScores: System.Collections.Generic.List[float]  # readonly
    MaxLMS: float  # readonly
    MaxQuality: float  # readonly
    MaxUniqueness: float  # readonly
    QualityScores: System.Collections.Generic.List[float]  # readonly
    RTSearchRange: DoubleRange  # readonly
    RTValues: System.Collections.Generic.List[float]  # readonly
    ScalingScores: System.Collections.Generic.List[float]  # readonly
    TotalHitCount: int  # readonly
    UniquenessScores: System.Collections.Generic.List[float]  # readonly

    def SortCandidatesByRT(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]: ...
    def SortCandidatesByQualityScore(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]: ...
    def SortCandidatesByLMS(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]: ...

class TargetCompound:  # Class
    @overload
    def __init__(
        self,
        cpdList: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList,
        index: int,
        name: str,
        cas: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        cpdList: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList,
        index: int,
        name: str,
        cas: str,
        formula: str,
        rt: float,
    ) -> None: ...

    CAS: str  # readonly
    CompoundList: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompoundList
    )  # readonly
    Formula: str  # readonly
    HasIsomers: bool  # readonly
    HasRT: bool  # readonly
    Index: int  # readonly
    IsomerSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.IsomerSet
    )  # readonly
    Name: str  # readonly
    ParsedFormula: (
        Agilent.MassSpectrometry.DataAnalysis.MFS.MolecularFormula
    )  # readonly
    RT: float  # readonly

class TargetCompoundList(
    Iterable[Any],
    Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ],
):  # Class
    def __init__(self, cpdListFilePath: str) -> None: ...

    CompoundListFile: str  # readonly
    Count: int  # readonly

    def GetCompoundByName(
        self, cpdName: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ): ...
    def GetCompoundByIndex(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ): ...
    def GetCompoundByCAS(
        self, cas: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    ): ...

class TargetHitGroupSelector:  # Class
    NAssignedCpds: int  # readonly
    NCompounds: int  # readonly
    SeparateScanConditions: bool  # readonly

    def GetAltHitGroupsForCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ]: ...
    def GetSelectedHitGroupForCompound(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CrossSampleTargetHitGroup
    ): ...
    def SelectTargetHitGroups(self) -> None: ...

class TargetHitInfo:  # Class
    Component: Agilent.MassSpectrometry.DataAnalysis.Component  # readonly
    ComponentInfo: ComponentInfo  # readonly
    ComponentRT: float  # readonly
    HitIndex: int  # readonly
    IsIsomer: bool  # readonly
    IsTopHit: bool  # readonly
    IsomerCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    IsomerName: str  # readonly
    MatchScore: float  # readonly
    RTRange: DoubleRange  # readonly
    RefIonFeatureCount: int  # readonly
    RefIonFeatures: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ]  # readonly
    ReferenceIons: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon
    ]  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    )  # readonly
    TargetCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    TargetName: str  # readonly

    def ContainsRefIon(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> bool: ...
    def GetRefIonFeature(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceIon,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
    ): ...

class TargetHitSearchInSample:  # Class
    def __init__(
        self,
        cpdFeaturesInSample: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CompoundFeaturesInSample,
        refLibrary: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.ReferenceSpectrumLibrary,
    ) -> None: ...

    Compound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetCompound
    )  # readonly
    NumResolutions: int  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.CalibrationSample
    )  # readonly
    TargetHits: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo
    ]  # readonly

    @overload
    def FindTargetHits(
        self, separateScanConditions: bool
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo
    ]: ...
    @overload
    def FindTargetHits(
        self,
        refIonFeatures: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.RefIonFeature
        ],
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodAssistant.TargetHitInfo
    ]: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import (
    CnEngine,
    IModificationUnit,
    SpectralPeak,
)
from .BasicTypes import ChromMetadata, MfeCompound, Peak3D, PeakList, Protein, TOFCalib
from .Mathematics import RangeDouble
from .Mfe import (
    CompoundFormationParameters,
    IEngineBlockUserParameters,
    IsotopeCharacter,
)

# Stubs for namespace: PersistanceFiles

class CompoundEvidenceReader:  # Class
    def __init__(self, filePath: str) -> None: ...

    FilePath: str  # readonly

    def ReadRawEic(self, mzRange: RangeDouble) -> List[float]: ...
    def ReadRawData(
        self, retentionTime: float, timeWidth: float, targetMz: List[RangeDouble]
    ) -> PersistanceFiles.CompoundEvidences: ...
    @staticmethod
    def CalculateEic(
        peakLists: List[PeakList],
        metadata: ChromMetadata,
        boundaries: List[float],
        eics: List[Sequence[PersistanceFiles.MfeFile.Signal]],
    ) -> None: ...
    def ReadCompoundAndItsRawData(
        self, mass: float, retentionTime: float
    ) -> PersistanceFiles.CompoundEvidences: ...

class CompoundEvidences:  # Class
    def __init__(self) -> None: ...

    CompoundEics: List[List[float]]
    CompoundMzs: List[RangeDouble]
    CompoundPeaks: List[SpectralPeak]
    RawEics: List[List[float]]
    RawSpectrum: List[SpectralPeak]
    RetentionTimes: List[float]
    TimeRange: RangeDouble

class EicFormationParameters(IEngineBlockUserParameters):  # Class
    def __init__(self) -> None: ...

class MfeFile:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def AppUpdateRmfeCompounds(
        filePath: str,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        compounds: List[MfeCompound],
        modificationCode: Dict[IModificationUnit, int],
        isotopeCharacter: IsotopeCharacter,
        blockIndex: int,
    ) -> None: ...
    @staticmethod
    def AppendUpdateCompounds(
        filePath: str,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        compounds: List[MfeCompound],
        blockIndex: int,
    ) -> None: ...
    @staticmethod
    def CreateChargeUnitCode(
        parameters: CompoundFormationParameters,
    ) -> Dict[IModificationUnit, int]: ...
    @staticmethod
    def AppendUpdatePeak3Ds(
        filePath: str,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        peaks: List[Peak3D],
        rtPeakWidth: float,
        minSpectralPeakHeight: float,
    ) -> None: ...
    @staticmethod
    def ReadCompounds(
        filePath: str, compoundInfoLevel: PersistanceFiles.MfeFile.FeatureInfoLevel
    ) -> List[MfeCompound]: ...
    @staticmethod
    def ReadFileInfo(filePath: str) -> PersistanceFiles.MfeFile.FileInfo: ...
    @staticmethod
    def ReadPeak3Ds(
        filePath: str,
        peak3DInfoLevel: PersistanceFiles.MfeFile.Peak3DInfoLevel,
        rtPeakWidth: float,
        minSpectralPeakHeight: float,
    ) -> List[Peak3D]: ...
    @overload
    @staticmethod
    def ReadSpectralPeakLists(
        filePath: str,
        rtRange: RangeDouble,
        mzRange: RangeDouble,
        totalNumberOfPeaksRead: int,
    ) -> List[PeakList]: ...
    @overload
    @staticmethod
    def ReadSpectralPeakLists(
        filePath: str,
    ) -> PersistanceFiles.SpectralPeakStorage: ...
    @overload
    @staticmethod
    def ReadSpectralPeakLists(
        filePath: str, rtRange: RangeDouble
    ) -> PersistanceFiles.SpectralPeakStorage: ...
    @staticmethod
    def CreateFileAndSaveGloblaHeader(
        filePath: str, metadata: ChromMetadata, calibs: List[TOFCalib]
    ) -> None: ...
    @staticmethod
    def AppUpdateEics(
        filePath: str,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        binBoundaries: List[float],
        signalBins: List[Sequence[PersistanceFiles.MfeFile.Signal]],
    ) -> None: ...
    @staticmethod
    def CreateFileAndSaveSpectralPeaks(
        filePath: str,
        peakLists: PersistanceFiles.SpectralPeakStorage,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        metadata: ChromMetadata,
    ) -> None: ...
    @staticmethod
    def ReadMetadata(filePath: str, calibs: List[TOFCalib]) -> ChromMetadata: ...
    @staticmethod
    def ReadProteins(
        filePath: str, proteinInfoLevel: PersistanceFiles.MfeFile.FeatureInfoLevel
    ) -> List[Protein]: ...
    @staticmethod
    def AppendUpdateProteins(
        filePath: str,
        engineBlockInfo: PersistanceFiles.MfeFile.BlockInfo,
        proteins: List[Protein],
    ) -> None: ...
    @staticmethod
    def UpdateRmfeCompounds(
        filePath: str,
        blockInfoRead: PersistanceFiles.MfeFile.BlockInfo,
        compounds: List[MfeCompound],
        blockIndex: int,
    ) -> None: ...
    @staticmethod
    def ReadAdductList(filePath: str) -> List[IModificationUnit]: ...

    # Nested Types

    class BlockInfo:  # Class
        def __init__(self) -> None: ...

        AlgorithmVersion: int
        BlockType: PersistanceFiles.MfeFile.BlockType
        CreatedByMfe: bool
        DataGlobalOffset: int
        FormatVersion: int
        ParameterGlobalOffset: int
        SaveResult: bool
        UserParameters: IEngineBlockUserParameters

    class BlockType(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Compounds: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        Eic: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        Peak3Ds: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        Proteins: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        RmfcCompounds: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        SpectralPeaks: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly
        Unknown: PersistanceFiles.MfeFile.BlockType = ...  # static # readonly

    class FeatureInfoLevel(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        FeatureAttributesOnly: PersistanceFiles.MfeFile.FeatureInfoLevel = (
            ...
        )  # static # readonly
        MostDetailed: PersistanceFiles.MfeFile.FeatureInfoLevel = (
            ...
        )  # static # readonly
        UpToPeak3DAttributes: PersistanceFiles.MfeFile.FeatureInfoLevel = (
            ...
        )  # static # readonly

    class FileInfo:  # Class
        def __init__(self) -> None: ...

        BlockInfos: System.Collections.Generic.List[PersistanceFiles.MfeFile.BlockInfo]
        FilePath: str
        Metadata: ChromMetadata
        VariableMetadataBlockOffset: int

    class Peak3DInfoLevel(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        MostDetailed: PersistanceFiles.MfeFile.Peak3DInfoLevel = (
            ...
        )  # static # readonly
        Peak3DAttributesOnly: PersistanceFiles.MfeFile.Peak3DInfoLevel = (
            ...
        )  # static # readonly

    class Signal:  # Struct
        def __init__(self, scanIndex: int, height: float) -> None: ...

        Height: float
        ScanIndex: int

class RmfeParameters(IEngineBlockUserParameters):  # Class
    def __init__(self) -> None: ...

    CorrelationParameters: CnEngine.UserParameters
    MinQualityScoreForBucket: float
    SamplePathAndScalings: Dict[str, float]

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, other: PersistanceFiles.RmfeParameters) -> bool: ...
    def BinaryWrite(self, writer: System.IO.BinaryWriter) -> None: ...
    def BinaryRead(self, reader: System.IO.BinaryReader) -> None: ...
    def GetHashCode(self) -> int: ...
    def CalculateDataBlockLength(self) -> int: ...

class SpectralPeakStorage(Iterable[Any], Iterable[PeakList]):  # Class
    def __init__(self, persistanceFilePath: str) -> None: ...

    Calibrations: List[TOFCalib]  # readonly
    MZRange: RangeDouble  # readonly
    SequenciallyAccessiblePeakLists: List[PeakList]  # readonly
    SpectraCount: int  # readonly
    TotalPeakCount: int  # readonly

    def GetEnumerator(self) -> Iterator[PeakList]: ...
    def FinishAdding(self) -> None: ...
    def AddPeakList(self, peaks: PeakList) -> None: ...
    def AddPeakLists(self, peakLists: List[PeakList]) -> None: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Configuration.Properties

class Resources:  # Class
    AppName: str  # static # readonly
    Caption_OutlierCategory_Blank: str  # static # readonly
    Caption_OutlierCategory_CC: str  # static # readonly
    Caption_OutlierCategory_Calibration: str  # static # readonly
    Caption_OutlierCategory_Custom: str  # static # readonly
    Caption_OutlierCategory_ISTD: str  # static # readonly
    Caption_OutlierCategory_LibraryMatchScore: str  # static # readonly
    Caption_OutlierCategory_Mass: str  # static # readonly
    Caption_OutlierCategory_MassMatchScore: str  # static # readonly
    Caption_OutlierCategory_Matrix: str  # static # readonly
    Caption_OutlierCategory_PeakResult: str  # static # readonly
    Caption_OutlierCategory_QC: str  # static # readonly
    Caption_OutlierCategory_Qualifier: str  # static # readonly
    Caption_OutlierCategory_ResponseCheck: str  # static # readonly
    Caption_OutlierCategory_Sample: str  # static # readonly
    Caption_OutlierCategory_Surrogate: str  # static # readonly
    Caption_Outlier_Accuracy: str  # static # readonly
    Caption_Outlier_AlternativePeak: str  # static # readonly
    Caption_Outlier_AverageResponseFactor: str  # static # readonly
    Caption_Outlier_AverageResponseFactorRSD: str  # static # readonly
    Caption_Outlier_BlankConcentration: str  # static # readonly
    Caption_Outlier_BlankResponse: str  # static # readonly
    Caption_Outlier_CCAverageResponseFactor: str  # static # readonly
    Caption_Outlier_CCISTDResponseRatio: str  # static # readonly
    Caption_Outlier_CCRelativeResponseFactor: str  # static # readonly
    Caption_Outlier_CCResponseRatio: str  # static # readonly
    Caption_Outlier_CCRetentionTime: str  # static # readonly
    Caption_Outlier_CCTime: str  # static # readonly
    Caption_Outlier_CalibrationRange: str  # static # readonly
    Caption_Outlier_CapacityFactor: str  # static # readonly
    Caption_Outlier_CurveFitR2: str  # static # readonly
    Caption_Outlier_CustomCalculation: str  # static # readonly
    Caption_Outlier_DQ_Accuracy: str  # static # readonly
    Caption_Outlier_DQ_BlankConcentration: str  # static # readonly
    Caption_Outlier_DQ_SampleAmount: str  # static # readonly
    Caption_Outlier_ISTDResponse: str  # static # readonly
    Caption_Outlier_ISTDResponsePercentDeviation: str  # static # readonly
    Caption_Outlier_IntegrationMetric: str  # static # readonly
    Caption_Outlier_LibraryMatchScore: str  # static # readonly
    Caption_Outlier_LimitOfDetection: str  # static # readonly
    Caption_Outlier_LimitOfQuantitation: str  # static # readonly
    Caption_Outlier_MassAccuracy: str  # static # readonly
    Caption_Outlier_MassMatchScore: str  # static # readonly
    Caption_Outlier_MatrixSpike: str  # static # readonly
    Caption_Outlier_MatrixSpikeDeviation: str  # static # readonly
    Caption_Outlier_MatrixSpikeGroupRecovery: str  # static # readonly
    Caption_Outlier_MatrixSpikePercentRecovery: str  # static # readonly
    Caption_Outlier_MethodDetectionLimit: str  # static # readonly
    Caption_Outlier_PeakFullWidthHalfMaximum: str  # static # readonly
    Caption_Outlier_PeakNotFound: str  # static # readonly
    Caption_Outlier_PeakPurity: str  # static # readonly
    Caption_Outlier_PeakResolutionFront: str  # static # readonly
    Caption_Outlier_PeakResolutionRear: str  # static # readonly
    Caption_Outlier_PeakSymmetry: str  # static # readonly
    Caption_Outlier_Plates: str  # static # readonly
    Caption_Outlier_QC: str  # static # readonly
    Caption_Outlier_QCLCSRecovery: str  # static # readonly
    Caption_Outlier_QC_RSD: str  # static # readonly
    Caption_Outlier_QValue: str  # static # readonly
    Caption_Outlier_QualifierCoelutionScore: str  # static # readonly
    Caption_Outlier_QualifierIntegrationMetric: str  # static # readonly
    Caption_Outlier_QualifierMassAccuracy: str  # static # readonly
    Caption_Outlier_QualifierPeakFullWidthHalfMaximum: str  # static # readonly
    Caption_Outlier_QualifierPeakNotFound: str  # static # readonly
    Caption_Outlier_QualifierPeakResolutionFront: str  # static # readonly
    Caption_Outlier_QualifierPeakResolutionRear: str  # static # readonly
    Caption_Outlier_QualifierPeakSymmetry: str  # static # readonly
    Caption_Outlier_QualifierRatio: str  # static # readonly
    Caption_Outlier_QualifierSaturationRecovery: str  # static # readonly
    Caption_Outlier_QualifierSignalToNoiseRatio: str  # static # readonly
    Caption_Outlier_RelativeResponseFactor: str  # static # readonly
    Caption_Outlier_RelativeRetentionTime: str  # static # readonly
    Caption_Outlier_RelativeStandardError: str  # static # readonly
    Caption_Outlier_ResponseCheck: str  # static # readonly
    Caption_Outlier_ResponseFactor: str  # static # readonly
    Caption_Outlier_RetentionTime: str  # static # readonly
    Caption_Outlier_SampleAmount: str  # static # readonly
    Caption_Outlier_SampleRSD: str  # static # readonly
    Caption_Outlier_SaturationRecovery: str  # static # readonly
    Caption_Outlier_SignalToNoiseRatio: str  # static # readonly
    Caption_Outlier_Surrogate: str  # static # readonly
    Caption_Outlier_SurrogatePercentRecovery: str  # static # readonly
    ColorScheme_Black: str  # static # readonly
    ColorScheme_Classic: str  # static # readonly
    ColorScheme_DarkGray: str  # static # readonly
    ColorScheme_LightGray: str  # static # readonly
    ColorScheme_Pear: str  # static # readonly
    ColorScheme_Standard: str  # static # readonly
    ConcentrationUnits: str  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    HiddenColumns: List[int]  # static # readonly
    MethodTaskColumns: List[int]  # static # readonly
    NumberFormats: List[int]  # static # readonly
    QuantAnalysis_CustomTools: List[int]  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    SampleType_Blank_EQ_Caption: str  # static # readonly
    SampleType_MatrixBlank_EQ_Caption: str  # static # readonly
    SampleType_MatrixDup_EQ_Caption: str  # static # readonly
    SampleType_Matrix_EQ_Caption: str  # static # readonly
    ShortAppName: str  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    AppCommandContext,
    CompoundFilterType,
    CompoundKeySortType,
    GridExportMode,
    InstrumentType,
    INumericCustomFormat,
    INumericFormat,
    MethodEditTaskMode,
    NormalizeType,
    OutlierCategories,
    OutlierColumns,
    OutlierFilterType,
    OutlierLimitType,
    OutlierTables,
    PrintPlotFitType,
    SampleRowId,
    TargetCompoundRowId,
    TargetQualifierRowId,
)
from .CompoundsAtAGlance import OrganizeType, Overlay, PeakAnnotationType, ReviewMode
from .ScriptEngine import IScriptEngine
from .Toolbar import IExplorerBarGroup, IToolbar, IToolbarsManager
from .UIUtils2.Utils import FindOperatorType

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF

class Application:  # Class
    def __init__(self) -> None: ...

    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # static # readonly

class CommandEventArgs(System.EventArgs):  # Class
    def __init__(self, commandName: str) -> None: ...

    Command: str

class IAddIn(object):  # Interface
    DisplayName: str  # readonly
    Enabled: bool
    Name: str  # readonly
    PathName: str  # readonly

    def Execute(self, parameters: List[Any]) -> Any: ...

class IAddInManager(object):  # Interface
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddIn: ...
    def GetIDs(self) -> List[str]: ...

class IAverageQualifierRatiosDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISelectRowsDialog
):  # Interface
    IncludesCalibrations: bool
    IncludesQCs: bool

class IAverageRetentionTimeDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISelectRowsDialog
):  # Interface
    IncludesCalibrations: bool
    IncludesQCs: bool
    UseWeighting: bool
    Weighting: float

class IBatchDataSet(object):  # Interface
    BatchState: str  # readonly
    BatchTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    CalibrationTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    PeakQualifierTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    PeakTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    TargetCompoundTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    TargetQualifierTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly

    def GetBatchAttribute(self, name: str) -> Any: ...

class ICalCurvePane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotControlPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
):  # Interface
    AssistantConfidenceBandVisible: bool
    CanAcceptAssistantCurve: bool  # readonly
    CurveFitAssistantTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICurveFitAssistantTable
    )  # readonly
    IsLogScaleX: bool
    IsLogScaleY: bool
    ShowCC: bool
    ShowIstdResponses: bool
    ShowQC: bool
    ShowRelativeConcentration: bool
    ShowStandardDeviationBars: bool

    def FitToLevels(self, levelNames: Iterable[str], includesOrigin: bool) -> None: ...
    def AcceptAssistantCurve(self) -> None: ...
    def CalibrationPointExists(self, sampleId: int) -> bool: ...
    def ShowPropertiesDialog(self) -> None: ...

class ICalibrationAtAGlance(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IWindow,
    System.Windows.Forms.IWin32Window,
):  # Interface
    NumPaneColumnsPerPage: int  # readonly
    NumPaneRowsPerPage: int  # readonly

    def Show(self) -> None: ...
    def Close(self) -> None: ...
    def GetSelectedTargetCompounds(self) -> List[TargetCompoundRowId]: ...
    def SetPaneDimension(self, rows: int, columns: int) -> None: ...

    WindowCreated: System.EventHandler  # Event

class IChromSpecPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotControlPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
):  # Interface
    CanClearManualIntegration: bool  # readonly
    CanFitToCalibrationLevel: bool  # readonly
    CanFitToPeak: bool  # readonly
    CanFitToPeakHeight: bool  # readonly
    CanManualIntegrate: bool  # readonly
    CanResetRTRange: bool  # readonly
    CanRestoreIntegrationSetup: bool  # readonly
    CanSearchLibrary: bool  # readonly
    CanShowDeconvolutedComponents: bool  # readonly
    CanShowIntegrationSetupDialog: bool  # readonly
    CanShowWiderRTRange: bool  # readonly
    CanZeroPeak: bool  # readonly
    ChromatogramXUnit: Agilent.MassSpectrometry.DataAnalysis.DataUnit
    FillPeaks: bool
    FitToHighestLevel: bool
    FitToLowestLevel: bool
    FitToPeak: bool
    FitToPeakHeight: bool
    IsSelectedPaneCompound: bool  # readonly
    IsSelectedPaneIstd: bool  # readonly
    IsSelectedPaneQualifier: bool  # readonly
    IsSelectedPaneSpectrum: bool  # readonly
    ManualIntegrateMode: bool  # readonly
    ManualScaleY: bool  # readonly
    NormalizeQualifiers: bool
    SelectedCompoundId: TargetCompoundRowId  # readonly
    SelectedQualifierId: TargetQualifierRowId  # readonly
    ShowBaselineCalculationPoints: bool
    ShowBaselines: bool
    ShowChromatogram: bool
    ShowDeconvolutedComponents: bool
    ShowIstd: bool
    ShowMatchScores: bool
    ShowOverrideSpectrum: bool
    ShowQualifierAnnotations: bool
    ShowQualifiers: bool
    ShowReferenceSpectrum: bool
    ShowSpectrum: bool
    ShowUncertaintyBand: bool

    def RestoreIntegrationSetup(self) -> None: ...
    def SetManualScaleY(self, miny: float, maxy: float) -> None: ...
    def SearchLibrary(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...
    def ShowWiderRTRange(self) -> None: ...
    def ResetRTRange(self) -> None: ...
    def ClearManualIntegration(self) -> None: ...
    def ZeroPeak(self) -> None: ...
    def ExitManualIntegrationMode(self) -> None: ...
    def GetActivePaneScale(
        self, minx: float, maxx: float, miny: float, maxy: float
    ) -> bool: ...
    def EnterManualIntegrationMode(self) -> None: ...
    def ShowIntegrationSetupDialog(self) -> None: ...
    def ShowPeakLabelsDialog(self) -> None: ...

class IChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IXYData
):  # Interface
    IChromatogram: Agilent.MassSpectrometry.DataAnalysis.IChromatogram  # readonly

class IChromatogramInformation(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IWindow,
    System.Windows.Forms.IWin32Window,
):  # Interface
    AnchorRows: int  # readonly
    HeadToTail: bool
    Items: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogramInformationItem
    ]  # readonly
    LinkXAxes: bool
    LinkYAxes: bool
    MaxNumVisibleRows: int
    Overlay: bool
    RowCount: int  # readonly

    def SelectAllGrid(self) -> None: ...
    def AutoScaleY(self) -> None: ...
    def CanAutoScale(self) -> bool: ...
    def GetPane(
        self, rowIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotPane: ...
    def ExportGraphics(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> None: ...
    def SetAllItemsVisible(self, visible: bool) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def CreateExportGraphicsParameters(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters
    ): ...
    def AutoScale(self) -> None: ...
    def GetSelectedPane(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotPane: ...
    def SetItemsVisible(
        self,
        items: List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogramInformationItem
        ],
        visible: bool,
    ) -> None: ...
    def Close(self) -> None: ...
    def ShowExportGraphicsDialog(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> System.Windows.Forms.DialogResult: ...
    def ShowExceptionMessage(self, ex: System.Exception) -> None: ...
    def CanCreateCompound(self) -> bool: ...
    def Show(self) -> None: ...
    def CreateCompound(self) -> None: ...
    def GetSignalsOfPane(self, rowIndex: int) -> List[
        System.Collections.Generic.KeyValuePair[
            int,
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo,
        ]
    ]: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...

    WindowCreated: System.EventHandler  # Event

class IChromatogramInformationItem(object):  # Interface
    BatchID: int  # readonly
    Color: System.Drawing.Color
    DataFileName: str  # readonly
    InstrumentName: str  # readonly
    SampleID: int  # readonly
    SampleName: str  # readonly
    ScanType: Optional[Agilent.MassSpectrometry.DataAnalysis.MSScanType]  # readonly
    Signal: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo
    )  # readonly
    Visible: bool
    _Item: (
        Agilent.MassHunter.Quantitative.UIModel.IChromatogramInformationItem
    )  # readonly

class ICompliance(object):  # Interface
    AlwaysAuditTrail: bool  # readonly
    ConnectionTicket: str  # readonly
    IsActive: bool  # readonly
    IsInstalled: bool  # readonly
    IsLocal: bool  # readonly
    Name: str  # readonly
    User: str  # readonly

    def IsUserValidationRequired(self, command: str) -> bool: ...
    def SetCommandReason(self, reason: str) -> None: ...
    def Impersonate(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IImpersonationContext
    ): ...
    def IsCommandReasonRequired(self, command: str) -> bool: ...
    def CheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def HasPermission(self, command: str) -> bool: ...
    @overload
    def TranslateToLocalPath(self, path: str) -> str: ...
    @overload
    def TranslateToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    @overload
    def ValidateUser(self, user: str, password: str) -> None: ...
    @overload
    def ValidateUser(
        self, user: System.Security.SecureString, password: System.Security.SecureString
    ) -> None: ...
    def IsBatchCheckedoutByCurrentUser(
        self, batchFolder: str, batchFile: str
    ) -> bool: ...
    def ValidateUserEncrypted(self, user: str, encryptedPassword: str) -> None: ...
    def UndoCheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...

class ICompoundGroupFilter(object):  # Interface
    CompoundGroup: str  # readonly
    FilterType: CompoundFilterType  # readonly

class ICompoundKey(
    System.IComparable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundKey
    ]
):  # Interface
    CompoundGroup: str  # readonly
    CompoundName: str  # readonly
    HasCompoundGroup: bool  # readonly
    HasTimeSegment: bool  # readonly
    TimeSegment: int  # readonly

class ICompoundsAtAGlance(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IWindow,
    System.Windows.Forms.IWin32Window,
):  # Interface
    AddInManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddInManager
    )  # readonly
    CanAutoScale: bool  # readonly
    CanCopyPage: bool  # readonly
    CanFitToCalibrationLevel: bool  # readonly
    CanFreezeColumns: bool  # readonly
    CanFreezePanes: bool  # readonly
    CanFreezeRows: bool  # readonly
    CanManualIntegrate: bool  # readonly
    CanNavigateBag: bool  # readonly
    CanShowManualIntegrateWindow: bool  # readonly
    CanUnfreezePanes: bool  # readonly
    CanUpdateRetentionTimes: bool  # readonly
    CanZeroPeakSelectedPanes: bool  # readonly
    CurrentReviewItemIndex: Optional[int]  # readonly
    FillPeaks: bool
    HasData: bool  # readonly
    HasNextReviewItem: bool  # readonly
    HasPreviousReviewItem: bool  # readonly
    IsManualIntegrating: bool  # readonly
    LinkAllXAxes: bool
    LinkAllYAxes: bool
    LinkXAxes: bool
    LinkYAxes: bool
    LinkYAxesVertically: bool
    Normalize: bool
    NumPaneColumnsPerPage: int  # readonly
    NumPaneRowsPerPage: int  # readonly
    OrganizeRows: OrganizeType  # readonly
    Overlay: Overlay  # readonly
    PeakAnnotations: List[PeakAnnotationType]
    ReviewItemCount: int  # readonly
    ReviewMode: ReviewMode  # readonly
    ShowBaselines: bool
    ShowPeakAnnotationNames: bool
    ShowPeakAnnotationUnits: bool
    ToolbarsManager: IToolbarsManager  # readonly
    Uncertainty: bool  # readonly
    WrapRows: bool  # readonly

    def FreezePanes(self) -> None: ...
    def MISplitRight(self) -> None: ...
    def FreezeRows(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def ShowExportGraphicsDialog(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> System.Windows.Forms.DialogResult: ...
    def ShowExceptionMessage(self, ex: System.Exception) -> None: ...
    def SelectAllPanes(self) -> None: ...
    def SetupGraphics(
        self,
        samplesFilter: str,
        samplesOrder: str,
        compoundsFilter: str,
        compoundsOrder: str,
        organizeRows: OrganizeType,
        overlay: Overlay,
        reviewMode: ReviewMode,
        wrapRows: bool,
        baselines: Optional[bool],
        fillPeaks: Optional[bool],
        normalize: Optional[bool],
        uncertainty: Optional[bool],
    ) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...
    def GetActivePaneScale(
        self, minx: float, maxx: float, miny: float, maxy: float
    ) -> bool: ...
    def MIMergeLeft(self) -> None: ...
    def ShowManualIntegrateWindow(self) -> None: ...
    def GotoPrevOutlierPane(self) -> bool: ...
    def MIDropBaseline(self) -> None: ...
    def CreateExportGraphicsParameters(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters
    ): ...
    def NavigateBag(self) -> None: ...
    def MovePreviousReviewItem(self) -> None: ...
    def SetCurrentLayoutAsDefault(self) -> None: ...
    def SetOutliers(self, columns: List[OutlierColumns]) -> None: ...
    def MIApplyISTDRTsToTargets(self) -> None: ...
    def AutoScaleAllPanes(self) -> None: ...
    def MIApplyTargetRTsToQualifiers(self) -> None: ...
    def MISplitLeft(self) -> None: ...
    def ZeroPeakSelectedPanes(self) -> None: ...
    def ShowHelpContents(self) -> None: ...
    def MoveNextReviewItem(self) -> None: ...
    def ShowHelpSearch(self) -> None: ...
    def UpdateRetentionTimes(self) -> None: ...
    def UnfreezePanes(self) -> None: ...
    def ExportGraphics(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> None: ...
    def PrintToPdf(self, file: str) -> None: ...
    def GetReviewItems(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IReviewItem
    ]: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def Close(self) -> None: ...
    def GetAvailableOutliers(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IOutlier
    ]: ...
    def ClearManualIntegration(self) -> None: ...
    def MISnapBaseline(self) -> None: ...
    def GotoNextOutlierPane(self) -> bool: ...
    def EndManualIntegration(self) -> None: ...
    def GetSelectedSamples(self) -> List[SampleRowId]: ...
    def ShowSetupGraphicsDialog(self) -> None: ...
    def ZeroPeak(self) -> None: ...
    def MIMergeRight(self) -> None: ...
    def Print(self) -> None: ...
    def MoveReviewItem(self, index: int) -> None: ...
    def GetOutliers(self) -> List[OutlierColumns]: ...
    def FreezeColumns(self) -> None: ...
    def GetToolbar(self, paneId: str, id: str) -> IToolbar: ...
    def SetPaneDimension(self, rows: int, columns: int) -> None: ...
    def ShowHelpIndex(self) -> None: ...
    def FitToPeak(self) -> None: ...
    def SetManualScaleY(self, miny: float, maxy: float) -> None: ...
    def ManualIntegrate(self) -> None: ...
    def Show(self) -> None: ...
    def FitToCalibrationLevel(self, lowest: bool) -> None: ...
    def CopyPage(self) -> None: ...
    def FitToPeakHeight(self) -> None: ...
    def GetSelectedCompounds(self) -> List[TargetCompoundRowId]: ...
    def AutoScale(self) -> None: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...

    WindowCreated: System.EventHandler  # Event

class ICurveFitAssistantTable(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IGrid
):  # Interface
    Visible: bool

class IDataRow(object):  # Interface
    def __getitem__(self, column: str) -> Any: ...
    def IsNull(self, column: str) -> bool: ...

class IDataTable(object):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow: ...
    Name: str  # readonly

    @overload
    def Select(
        self, filterExpression: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow
    ]: ...
    @overload
    def Select(
        self, filterExpression: str, sort: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow
    ]: ...
    def GetColumnNames(self) -> List[str]: ...

class IEditMethodState(object):  # Interface
    AcquisitionSamplePath: str  # readonly
    CurrentIstdCompoundName: str  # readonly
    CurrentLevelId: int  # readonly
    CurrentObjectIsCalibration: bool  # readonly
    CurrentObjectIsSample: bool  # readonly
    CurrentObjectIsTargetCompound: bool  # readonly
    CurrentObjectIsTargetQualifier: bool  # readonly
    CurrentTargetCompoundId: int  # readonly
    CurrentTargetQualifierId: int  # readonly
    IsDirty: bool  # readonly
    MethodFilePathName: str  # readonly
    TargetCompoundRow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow
    )  # readonly

    def NavigateQualifier(self, compoundId: int, qualifierId: int) -> None: ...
    def ValidateMethod(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodValidationMessage
    ]: ...
    def NavigateCalibration(self, compoundId: int, levelId: int) -> None: ...
    def GetTimeSegments(self) -> List[int]: ...
    def GetCompoundChromatogram(
        self, compoundId: int, minRT: float, maxRT: float
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def GetQualifierChromatogram(
        self, compoundId: int, qualifierId: int, minRT: float, maxRT: float
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def NavigateCompound(self, compoundId: int) -> None: ...
    @overload
    def GetCompoundSpectrum(
        self, compoundId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    @overload
    def GetCompoundSpectrum(
        self, compoundId: int, minRT: float, maxRT: float
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...

class IExportPlotParameters(object):  # Interface
    AllPanes: bool
    FilePath: str
    FitType: PrintPlotFitType
    ImageFormat: System.Drawing.Imaging.ImageFormat
    PageSize: System.Drawing.SizeF
    Zoom: float

    def ReadFromConfiguration(self) -> None: ...
    def SaveToConfiguration(self) -> None: ...

class IGrid(object):  # Interface
    ActiveBandName: str  # readonly
    ActiveColumnName: str  # readonly
    CanExpandAll: bool  # readonly
    ContainsFocus: bool  # readonly
    IsInEditMode: bool  # readonly
    LastLogicalBandName: str  # readonly
    LastLogicalColumnName: str  # readonly
    LastRawBandName: str  # readonly
    LastRawColumnName: str  # readonly

    def CanUndoInEditMode(self) -> bool: ...
    def FormatColumn(self, rawBandName: str, rawColumnName: str) -> None: ...
    def ColumnExists(self, rawBandName: str, rawColumnName: str) -> bool: ...
    @overload
    def ExportToXml(self, file: str) -> None: ...
    @overload
    def ExportToXml(self, file: str, mode: GridExportMode) -> None: ...
    def Sort(self, rawBandName: str, rawColumnName: str, ascending: bool) -> None: ...
    def AutoFitColumns(self) -> None: ...
    def CollapseAll(self) -> None: ...
    def IsColumnFormattable(self, rawBandName: str, rawColumnName: str) -> bool: ...
    def GetColumnCaption(self, logicalBandName: str, logicalColumnName: str) -> str: ...
    def LoadColumnSettings(self, file: str) -> None: ...
    def FindNext(
        self,
        tableName: str,
        columnName: str,
        operatorType: FindOperatorType,
        value_: Any,
    ) -> bool: ...
    def GetLogicalColumnName(self, rawBandName: str, rawColumnName: str) -> str: ...
    def ShowColumn(
        self, logicalBandName: str, logicalColumnName: str, columnNameAfter: str
    ) -> None: ...
    def UndoInEditMode(self) -> None: ...
    def GetLogicalBandName(self, rawBandName: str, rawColumnName: str) -> str: ...
    def GetSelectedRows(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IGridRow
    ]: ...
    def ExpandAll(self) -> None: ...
    def SupportsSaveLoadColumnSettings(self) -> bool: ...
    @overload
    def ExportToText(self, file: str, delimiter: str) -> None: ...
    @overload
    def ExportToText(self, file: str, delimiter: str, mode: GridExportMode) -> None: ...
    def IsColumnVisible(self, logicalBandName: str, logicalColumnName: str) -> bool: ...
    def SaveColumnSettings(self, file: str) -> None: ...
    def GetColumnNames(self, logicalBandName: str) -> List[str]: ...
    def ResetColumns(self) -> None: ...
    @overload
    def ExportToExcel(self, file: str) -> None: ...
    @overload
    def ExportToExcel(self, file: str, mode: GridExportMode) -> None: ...
    def ResetSort(self) -> None: ...
    def HideColumn(self, logicalBandName: str, logicalColumnName: str) -> None: ...
    def ShowColumnsDialog(self) -> None: ...

class IGridRow(object):  # Interface
    BandName: str  # readonly
    def __getitem__(self, columnName: str) -> Any: ...

class IISTDFilter(object):  # Interface
    FilterType: CompoundFilterType  # readonly
    ISTD: str  # readonly
    ISTDCompoundId: int  # readonly

class IImpersonationContext(System.IDisposable):  # Interface
    ...

class ILibrarySearchWindow(object):  # Interface
    def Search(self) -> None: ...
    @overload
    def SetTargetSpectrum(
        self, spectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum
    ) -> None: ...
    @overload
    def SetTargetSpectrum(
        self,
        spectrum: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum,
    ) -> None: ...
    def ShowWindow(self) -> None: ...
    def SetLibraryMethod(self, methodPath: str) -> None: ...

class IMainFrame(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IWindow,
    System.Windows.Forms.IWin32Window,
):  # Interface
    def Layout(self, pattern: int) -> None: ...
    def ResetLayout(self) -> None: ...
    def ShowBatchPropertiesDialog(self) -> None: ...
    def ShowHelpIndex(self) -> None: ...
    def ShowHelpQuantitationDataSet(self) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def ShowOutlierNavigator(self) -> None: ...
    def ShowOptionsDialog(self) -> None: ...
    def MaximizePane(self, paneKey: str) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def GetToolbar(self, id: str) -> IToolbar: ...
    def ShowHelpSearch(self) -> None: ...
    def ShowHelpContents(self) -> None: ...

class IMethodDataSet(object):  # Interface
    CalibrationTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    TargetCompoundTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly
    TargetQualifierTable: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataTable
    )  # readonly

    def GetGlobal(self, name: str) -> Any: ...

class IMethodErrorListPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
):  # Interface
    def ShowMessages(self, messages: Any) -> None: ...
    def ValidateMethod(self, alwaysShowPane: bool) -> None: ...

class IMethodTablePane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IGrid,
):  # Interface
    ArrangeCompoundsBy: str
    CalibrationsBandVisible: bool
    CanBrowseAcquisitionMethod: bool  # readonly
    CanDeleteRows: bool  # readonly
    CanFillDown: bool  # readonly
    CanGroupByTimeSegment: bool  # readonly
    CompoundsBandVisible: bool
    GroupByTimeSegment: bool
    HasNextCompound: bool  # readonly
    HasPreviousCompound: bool  # readonly
    OutlierSetup: OutlierColumns
    QualifiersBandVisible: bool
    TaskMode: MethodEditTaskMode
    TimeSegmentFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ITimeSegmentFilter
    )  # readonly

    def SetTimeSegmentFilter(
        self, filterType: CompoundFilterType, timeSegment: int
    ) -> None: ...
    def GetSelectedCompoundIds(self) -> List[int]: ...
    def PreviousCompound(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...
    def GetFilteredCompoundIds(self) -> List[int]: ...
    def DeleteRows(self) -> None: ...
    @overload
    def ActivateCell(self, columnName: str) -> None: ...
    @overload
    def ActivateCell(self, compoundId: int, columnName: str) -> None: ...
    def NextCompound(self) -> None: ...
    def BrowseAcquisitionMethod(self) -> None: ...
    def FillDown(self) -> None: ...

class IMethodTasksPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
):  # Interface
    def GetGroup(self, id: str) -> IExplorerBarGroup: ...

class IMethodValidationMessage(object):  # Interface
    ColumnName: str  # readonly
    IsError: bool  # readonly
    IsInfo: bool  # readonly
    IsWarning: bool  # readonly
    Message: str  # readonly
    TableName: str  # readonly

    def GetRowId(self) -> List[int]: ...

class IMetricsPlot(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotControlPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
):  # Interface
    DrawAverageStdDevLines: bool

    @overload
    def AddSeriesToActivePane(self, column: str) -> None: ...
    @overload
    def AddSeriesToActivePane(
        self, column: str, color: System.Drawing.Color
    ) -> None: ...
    def Clear(self) -> None: ...
    def IsPlottableColumn(self, column: str) -> bool: ...

class INumberFormat(INumericFormat):  # Interface
    def GetColumns(self) -> List[str]: ...
    @overload
    def SetFormat(self, column: str, formatString: str) -> None: ...
    @overload
    def SetFormat(self, column: str, format: INumericCustomFormat) -> None: ...
    def GetFormatString(self, column: str) -> str: ...
    def GetColumnCategory(self, column: str) -> str: ...
    def StoreFormats(self) -> None: ...
    def NotifyFormatChange(self) -> None: ...

class IOutlier(object):  # Interface
    Category: OutlierCategories  # readonly
    Column: OutlierColumns  # readonly
    FlagColumn: str  # readonly
    IsAvailable: bool  # readonly
    Table: OutlierTables  # readonly
    ValueColumn: str  # readonly

    def GetPrerequisiteColumns(self) -> List[str]: ...
    def GetOutlierInfo(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IOutlierInfo: ...

class IOutlierDetector(object):  # Interface
    def GetOutlier(
        self, outlierColumn: OutlierColumns
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IOutlier: ...

class IOutlierInfo(object):  # Interface
    Deteil: str  # readonly
    LimitType: OutlierLimitType  # readonly
    Limits: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IOutlierLimits
    )  # readonly
    Message: str  # readonly
    Name: str  # readonly
    Value: Any  # readonly

class IOutlierLimits(object):  # Interface
    Max: float  # readonly
    Min: float  # readonly

class IPane(object):  # Interface
    CanCopy: bool  # readonly
    CanDelete: bool  # readonly
    CanPaste: bool  # readonly
    CanPrint: bool  # readonly
    Visible: bool

    def Copy(self) -> None: ...
    def GetToolbarIds(self) -> List[str]: ...
    def Print(self, displayDialog: bool) -> None: ...
    def PageSetup(self) -> None: ...
    def Delete(self) -> None: ...
    def Paste(self) -> None: ...
    def GetToolbar(self, id: str) -> IToolbar: ...
    def Activate(self) -> None: ...
    def PrintPreview(self) -> None: ...

class IPlotControlPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
):  # Interface
    AnchorColumns: int  # readonly
    AnchorRows: int  # readonly
    AutoScale: bool
    CanAutoScale: bool  # readonly
    CanExport: bool  # readonly
    CanNextZoom: bool  # readonly
    CanPrevZoom: bool  # readonly
    ColumnCount: int  # readonly
    RowCount: int  # readonly

    def GetActiveObject(self) -> T: ...
    def AutoScaleY(self) -> None: ...
    def PrevZoom(self) -> None: ...
    def GetPane(
        self, rowIndex: int, columnIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotPane: ...
    def ShowExportDialog(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> System.Windows.Forms.DialogResult: ...
    def CreateExportParameters(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters
    ): ...
    def Export(
        self,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IExportPlotParameters,
    ) -> None: ...
    def AutoScaleX(self) -> None: ...
    def PrintToPdf(self, file: str) -> None: ...
    def NextZoom(self) -> None: ...
    def DrawPage(
        self,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
        x: float,
        y: float,
        width: float,
        height: float,
        paintBackground: bool,
        anchoring: bool,
    ) -> None: ...

class IPlotPane(object):  # Interface
    MaxX: float
    MaxY: float
    MinX: float
    MinY: float
    Size: System.Drawing.Size  # readonly

    def AutoScaleY(self) -> None: ...
    @overload
    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    @overload
    def Draw(
        self,
        graphics: Agilent.MassSpectrometry.GUI.Plot.IGraphics,
        x: float,
        y: float,
        width: float,
        height: float,
        ignoreLinkedAxis: bool,
        paintBackground: bool,
    ) -> None: ...
    def AutoScaleX(self) -> None: ...

class IReport(object):  # Interface
    def QuickReport(self, templateFile: str, outputFile: str) -> None: ...

class IReportTaskQueue(object):  # Interface
    IsRunning: bool  # readonly

    def ShowQueueViewer(self) -> None: ...
    def Run(self) -> None: ...

class IReviewItem(object):  # Interface
    DisplayText: str  # readonly

class ISampleDataPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPlotControlPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
):  # Interface
    AnchorChromatogram: bool
    CanCreateNewTargetCompound: bool  # readonly
    CanCreateNewTargetQualifier: bool  # readonly
    CanExtractSpectrum: bool  # readonly
    CanFindCompounds: bool  # readonly
    CanNormalizeEachX: bool  # readonly
    CanSearchLibrary: bool  # readonly
    HasSpectrumPanes: bool  # readonly
    MaxNumVisibleRows: int
    NormalizeType: NormalizeType
    OverlayAllSignals: bool
    OverlayIstdCompounds: bool
    OverlayTargetCompounds: bool
    SampleDataPath: str  # readonly
    ShowCurrentCompound: bool
    ShowTic: bool

    def GetDisplayedSignals(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo
    ]: ...
    def FindCompounds(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...
    def SearchLibrary(self) -> None: ...
    def GetMSScanColor(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Drawing.Color: ...
    def CreateNewTargetQualifier(self) -> None: ...
    def GetSignalColor(
        self,
        signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo,
    ) -> System.Drawing.Color: ...
    def CreateNewTargetCompound(self) -> None: ...
    def HideSignal(
        self,
        signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo,
    ) -> None: ...
    def ClearSpectrumPanes(self) -> None: ...
    def DisplayMSScan(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType, show: bool
    ) -> None: ...
    def GetAvailableMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def GetAvailableSignals(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo
    ]: ...
    def GetDisplayedMSScanTypes(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.MSScanType]: ...
    def DisplaySignal(
        self,
        signal: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo,
    ) -> None: ...
    def ExtractSpectrum(self) -> None: ...

class IScriptEngine(object):  # Interface
    CurrentScope: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope
    )  # readonly
    DebugMode: bool  # readonly
    Engine: IScriptEngine  # readonly
    Globals: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope
    )  # readonly

    def CreateScope(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope: ...
    def ExecuteFile(
        self,
        file: str,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptScope,
    ) -> Any: ...

class IScriptInterface(object):  # Interface
    BatchDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IBatchDataSet
    )  # readonly
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompliance
    )  # readonly
    MethodDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodDataSet
    )  # readonly
    OutlierDetector: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IOutlierDetector
    )  # readonly
    ReportTaskQueue: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IReportTaskQueue
    )  # readonly
    ScriptEngine: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptEngine
    )  # readonly
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # readonly
    _ScriptInterface: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptInterface
    )  # readonly

    def _WritePrivateProfileString(
        self, section: str, key: str, value_: str, fileName: str
    ) -> int: ...
    def PreCommandSetReason(self, reason: str) -> None: ...
    def _GetPrivateProfileString(
        self, section: str, key: str, defaultValue: str, fileName: str
    ) -> str: ...
    def PreCommandValidateUserEncrypted(
        self, user: str, encryptedPassword: str
    ) -> None: ...
    @overload
    def PreCommandValidateUser(self, user: str, password: str) -> None: ...
    @overload
    def PreCommandValidateUser(
        self, user: System.Security.SecureString, password: System.Security.SecureString
    ) -> None: ...

class IScriptPane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
):  # Interface
    def Run(self) -> None: ...
    def Clear(self) -> None: ...

class IScriptScope(object):  # Interface
    def GetVariableNames(self) -> Iterable[str]: ...
    def RemoveVariable(self, name: str) -> None: ...
    def GetVariable(self, name: str) -> Any: ...
    def ContainsVariable(self, name: str) -> bool: ...
    def SetVariable(self, name: str, value_: Any) -> None: ...

class ISelectRowsDialog(object):  # Interface
    HelpId: int
    InitialSelectionCondition: str
    LabelText: str
    MethodTable: bool
    MultipleSelection: bool
    RowFilter: str
    SelectionCount: int  # readonly
    Table: str
    Title: str

    @overload
    def AddColumn(self, columnName: str, caption: str) -> None: ...
    @overload
    def AddColumn(
        self, columnName: str, caption: str, format: INumericCustomFormat
    ) -> None: ...
    def ShowDialog(self) -> System.Windows.Forms.DialogResult: ...
    def GetSelectedRow(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow: ...
    def ClearColumns(self) -> None: ...

class IShiftRetentionTimeDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISelectRowsDialog
):  # Interface
    AbsoluteShift: float
    RelativeShift: float

class ISignalInfo(
    System.IComparable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISignalInfo
    ]
):  # Interface
    DeviceName: str  # readonly
    IsMS: bool  # readonly
    OrdinalNumber: int  # readonly
    SignalName: str  # readonly

class ISpectrum(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IXYData
):  # Interface
    ISpectrum: Agilent.MassSpectrometry.DataAnalysis.ISpectrum  # readonly

class IStatusBar(object):  # Interface
    Visible: bool

class ITimeSegmentFilter(object):  # Interface
    FilterType: CompoundFilterType  # readonly
    TimeSegment: int  # readonly

class IUIState(object):  # Interface
    ActivePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
    )  # readonly
    ActiveWindow: System.Windows.Forms.IWin32Window  # readonly
    AddIns: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddInManager
    )  # readonly
    ApplicationPath: str  # readonly
    ApplicationType: str  # readonly
    BatchDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IBatchDataSet
    )  # readonly
    BatchDirectory: str  # readonly
    BatchFileName: str  # readonly
    BuildNumber: str  # readonly
    CalCurvePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICalCurvePane
    )  # readonly
    CalibrationAtAGlanceView: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICalibrationAtAGlance
    )  # readonly
    CanEditMethod: bool  # readonly
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    ChromSpecPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromSpecPane
    )  # readonly
    ChromatogramInformationView: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogramInformation
    )  # readonly
    CompoundsAtAGlanceView: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundsAtAGlance
    )  # readonly
    Constants: Dict[str, str]  # readonly
    CurrentBatchId: int  # readonly
    CurrentCompoundId: int  # readonly
    CurrentIstdCompoundId: int  # readonly
    CurrentIstdCompoundName: str  # readonly
    CurrentLevelId: int  # readonly
    CurrentPeakId: int  # readonly
    CurrentQualifierId: int  # readonly
    CurrentSampleId: int  # readonly
    CurrentVersion: str  # readonly
    CustomerHome: str  # readonly
    EditMethodState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IEditMethodState
    )  # readonly
    EditingMethod: bool  # readonly
    HasBatch: bool  # readonly
    HasIstd: bool  # readonly
    InstrumentType: InstrumentType  # readonly
    IsAuditTrailing: bool  # readonly
    IsBatchDirty: bool  # readonly
    IsCommandRunning: bool  # readonly
    IsCurrentSampleValid: bool  # readonly
    IsCurrentTargetCompoundValid: bool  # readonly
    IsInCommandGroup: bool  # readonly
    LibrarySearchWindow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ILibrarySearchWindow
    )  # readonly
    MainFrame: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMainFrame
    )  # readonly
    MethodDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodDataSet
    )  # readonly
    MethodErrorListPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodErrorListPane
    )  # readonly
    MethodTablePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodTablePane
    )  # readonly
    MethodTasksPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMethodTasksPane
    )  # readonly
    MetricsPlot: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IMetricsPlot
    )  # readonly
    NumericFormat: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.INumberFormat
    )  # readonly
    Report: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IReport
    )  # readonly
    SampleDataPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISampleDataPane
    )  # readonly
    ScriptInterface: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptInterface
    )  # readonly
    ScriptPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IScriptPane
    )  # readonly
    StatusBar: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IStatusBar
    )  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    ToolbarsManager: IToolbarsManager  # readonly
    Workflows: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddInManager
    )  # readonly
    WorktablePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IWorktablePane
    )  # readonly
    _AppCommandContext: AppCommandContext  # readonly
    _DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    _MainForm: Agilent.MassHunter.Quantitative.UIModel.IMainWindow  # readonly

    def CreateSelectRowsDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISelectRowsDialog
    ): ...
    def GetTargetCompoundChromatogram(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def Undo(self) -> None: ...
    def AddRecentBatch(self, batchPath: str, batchFile: str) -> None: ...
    def ShowAboutBox(self) -> None: ...
    def Redo(self) -> None: ...
    def GetCurrentTargetCompoundRow(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow: ...
    def GetTargetCompoundSpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    def CreateShiftRetentionTimeDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IShiftRetentionTimeDialog
    ): ...
    def CreateAverageQualifierRatiosDialog(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAverageQualifierRatiosDialog
    ): ...
    def NavigateCompound(self, compoundId: int) -> None: ...
    def ShowExceptionMessage(self, ex: System.Exception) -> None: ...
    @overload
    def GetTIC(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    @overload
    def GetTIC(
        self,
        level: Agilent.MassSpectrometry.DataAnalysis.MSLevel,
        scanTypes: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        minRT: float,
        maxRT: float,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def EndRunScript(self, result: System.IAsyncResult) -> Any: ...
    def GetIstdCompoundChromatogram(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def BeginCommandGroup(self) -> None: ...
    @overload
    def ExecuteCommandWithProgressDialog(
        self, commandType: System.Type, parameters: List[Any]
    ) -> Any: ...
    @overload
    def ExecuteCommandWithProgressDialog(
        self,
        parent: System.Windows.Forms.IWin32Window,
        commandType: System.Type,
        parameters: List[Any],
    ) -> Any: ...
    def GetCompoundSpectrum(
        self, sampleId: int, compoundId: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    def ShowAuditTrailView(self) -> None: ...
    def GetIstdCompoundSpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    def ClearRecentBatches(self) -> None: ...
    def SaveGraphicsSettingsTo(self, file: str) -> None: ...
    def GetRecentBatches(self) -> List[str]: ...
    def GetCompoundChromatogram(
        self, sampleId: int, compoundId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def CreateAverageRetentionTimeDialogs(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAverageRetentionTimeDialog
    ): ...
    def NavigateSample(self, sampleId: int) -> None: ...
    def ExceptionAbort(self, ex: System.Exception) -> None: ...
    def GetCurrentSampleRow(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow: ...
    def GetReferenceLibrarySpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    def BeginRunScript(
        self, stream: System.IO.Stream, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def GetPane(
        self, paneId: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane: ...
    def GetQualifierChromatogram(
        self, sampleId: int, compoundId: int, qualifierId: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IChromatogram
    ): ...
    def SaveConfiguration(self) -> None: ...
    def GetTargetCompoundSpectrumForReferenceLibraryMatch(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ISpectrum: ...
    def CloseMainForm(self) -> None: ...
    def ExecuteCommand(
        self,
        parent: System.Windows.Forms.IWin32Window,
        commandType: System.Type,
        parameters: List[Any],
    ) -> Any: ...
    def PerformCompliancePreCommand(
        self, parent: System.Windows.Forms.IWin32Window, commandName: str, action: str
    ) -> bool: ...
    def RunScript(self, file: str) -> Any: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...
    def EndCommandGroup(self) -> None: ...

    CommandEnd: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.CommandEventArgs
    ]  # Event
    CommandGroupEnded: System.EventHandler  # Event
    CommandGroupStarted: System.EventHandler  # Event
    CommandStart: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.CommandEventArgs
    ]  # Event
    NavigateChanged: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.NavigateChangeEventArgs
    ]  # Event

class IWindow(object):  # Interface
    Height: int
    Location: System.Drawing.Point
    Width: int

    Closed: System.EventHandler  # Event

class IWorktablePane(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IGrid,
):  # Interface
    ArrangeCompoundsBy: CompoundKeySortType
    CanFillDown: bool  # readonly
    CanStartAutoReview: bool  # readonly
    CompoundGroupFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundGroupFilter
    )
    CompoundKey: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundKey
    )
    CompoundListTableMode: bool
    DisplayAllSampleGroups: bool
    DisplayAllSampleTypes: bool
    FilterOutliers: bool
    FlagOutliers: bool
    FlatTableMode: bool
    HasNextCompound: bool  # readonly
    HasNextSample: bool  # readonly
    HasPreviousCompound: bool  # readonly
    HasPreviousSample: bool  # readonly
    HorizontalNestedTableMode: bool
    ISTDFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IISTDFilter
    )
    LockSampleColumns: bool
    OutlierFilterType: OutlierFilterType
    SingleCompoundMode: bool
    TimeSegmentFilter: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ITimeSegmentFilter
    )
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # readonly
    VerticalNestedTableMode: bool

    def GetFilteredSamples(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IDataRow
    ]: ...
    def FillDown(self) -> None: ...
    def NextCompound(self) -> None: ...
    def GetISTDFilters(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IISTDFilter
    ]: ...
    def ShowPropertiesDialog(self) -> None: ...
    def StartAutoReview(self, reviewCompounds: bool) -> None: ...
    def SetDisplaySampleType(self, type: str, display: bool) -> None: ...
    def ShowSelectOutliersDialog(self) -> None: ...
    def GetDisplaySampleGroup(self, group: str) -> bool: ...
    def GetTimeSegmentFilters(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ITimeSegmentFilter
    ]: ...
    def NextSample(self) -> None: ...
    def DeleteSelectedSamples(self) -> None: ...
    def GetDisplaySampleType(self, type: str) -> bool: ...
    def EnableOutlier(self, outlier: OutlierColumns, enable: bool) -> None: ...
    def GetCompoundGroupFilters(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundGroupFilter
    ]: ...
    def PreviousSample(self) -> None: ...
    def GetDisplayedSampleGroups(self) -> List[str]: ...
    def CanDeleteSelectedSamples(self) -> bool: ...
    def GetSelectedSamples(self) -> List[SampleRowId]: ...
    def GetDisplayedSampleTypes(self) -> List[str]: ...
    def SetDisplaySampleGroup(self, group: str, display: bool) -> None: ...
    def GetFilteredCompoundKeys(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.ICompoundKey
    ]: ...
    def RefreshSampleFilter(self) -> None: ...
    def PreviousCompound(self) -> None: ...

class IXYData(object):  # Interface
    Count: int  # readonly
    MaxX: float  # readonly
    MaxY: float  # readonly
    MinX: float  # readonly
    MinY: float  # readonly
    Title: str  # readonly

    def GetX(self, index: int) -> float: ...
    def GetY(self, index: int) -> float: ...

class NavigateChangeEventArgs(System.EventArgs):  # Class
    def __init__(
        self,
        prevSampleId: int,
        prevCompoundId: int,
        newSampleId: int,
        newCompoundId: int,
    ) -> None: ...

    NewCompoundId: int  # readonly
    NewSampleId: int  # readonly
    PreviousCompoundId: int  # readonly
    PreviousSampleId: int  # readonly

class Utils:  # Class
    @staticmethod
    def TryCast(obj: Any) -> T: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Mathematics import RangeDouble, Regression

# Stubs for namespace: CorrelationNormalizationEngine3

class TimeShiftModeler:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def SafeConstructModel(
        initialModel: Regression,
        observations: Sequence[Regression.Observation],
        damping: float,
        modelApplicableRange: RangeDouble,
        degreeOfFreedom: int,
    ) -> Regression: ...
    @staticmethod
    def Model(
        modelApplicationRange: RangeDouble,
        observations: Sequence[Regression.Observation],
    ) -> Regression: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Renderer.Graphics

class Canvas(
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.IGraphics,
    Agilent.MassHunter.ReportBuilder.Engine.IGraphicsCanvas,
    Agilent.MassSpectrometry.GUI.Plot.GraphicsWrap,
):  # Class
    def __init__(self, gr: System.Drawing.Graphics) -> None: ...

    IgnoreFontName: bool

    def DrawImage(
        self,
        image: System.Drawing.Image,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def GetGraphics(self) -> T: ...
    def DrawXps(self, stream: System.IO.Stream) -> None: ...
    def ConvertBounds(
        self, bounds: System.Drawing.RectangleF
    ) -> System.Drawing.RectangleF: ...
    def Dispose(self) -> None: ...

class Renderer(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer
):  # Class
    @overload
    def __init__(
        self,
        graphics: System.Drawing.Graphics,
        pageBound: System.Drawing.RectangleF,
        marginBound: System.Drawing.RectangleF,
    ) -> None: ...
    @overload
    def __init__(
        self,
        graphics: System.Drawing.Graphics,
        pageBound: System.Drawing.RectangleF,
        marginBound: System.Drawing.RectangleF,
        pageNum: int,
        totalPages: int,
    ) -> None: ...

    Context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext

    def RenderImage(
        self, image: Agilent.MassHunter.ReportBuilder.Template.IImage
    ) -> None: ...
    def StartDocument(self) -> None: ...
    def PageBreak(self) -> None: ...
    def RenderTable(
        self, numColumns: int
    ) -> Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer: ...
    def RenderGraphics(
        self, graphics: Agilent.MassHunter.ReportBuilder.Template.IGraphics
    ) -> None: ...
    def RenderText(
        self, textbox: Agilent.MassHunter.ReportBuilder.Template.ITextbox
    ) -> None: ...
    def EndDocument(self) -> None: ...
    def SetPage(
        self, page: Agilent.MassHunter.ReportBuilder.Template.IPage
    ) -> None: ...
    def Dispose(self) -> None: ...

class TableRenderer(Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer):  # Class
    def __init__(
        self, renderer: Agilent.MassHunter.ReportBuilder.Renderer.Graphics.Renderer
    ) -> None: ...
    def SetColumnWidths(self, widths: List[float]) -> None: ...
    def EndTable(self) -> None: ...
    def SetProperties(
        self, table: Agilent.MassHunter.ReportBuilder.Template.ITable
    ) -> None: ...
    def StartHeader(self) -> None: ...
    def EndHeader(self) -> None: ...
    def AddCell(
        self, cell: Agilent.MassHunter.ReportBuilder.Template.ITableCell
    ) -> None: ...
    def EndRow(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import MainWindow
from .Models import IAppCommandContext, IDynamicCalibrationSetupModel

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ScriptIF

class IMainWindow(object):  # Interface
    _Window: System.Windows.Window  # readonly

    def Close(self) -> None: ...

class IUIState(object):  # Interface
    CommandContext: IAppCommandContext  # readonly
    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    MainWindow: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ScriptIF.IMainWindow
    )  # readonly

class MainWindow(
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ScriptIF.IMainWindow
):  # Class
    def __init__(self, window: MainWindow) -> None: ...

    _Window: System.Windows.Window  # readonly

    def Close(self) -> None: ...

class UIState(
    Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ScriptIF.IUIState
):  # Class
    def __init__(
        self, mainWindow: MainWindow, model: IDynamicCalibrationSetupModel
    ) -> None: ...

    CommandContext: IAppCommandContext  # readonly
    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    MainWindow: (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ScriptIF.IMainWindow
    )  # readonly
